@@ -1,9 +1,8 @@
 package Pod::Weaver::Section::GenerateSection;
-our $AUTHORITY = 'cpan:CDRAUG';
-$Pod::Weaver::Section::GenerateSection::VERSION = '1.02';
+$Pod::Weaver::Section::GenerateSection::VERSION = '1.03';
 use utf8;
 
-## Copyright (C) 2013-2016 Carnë Draug <carandraug+dev@gmail.com>
+## Copyright (C) 2013-2017 Carnë Draug <carandraug+dev@gmail.com>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -20,9 +19,13 @@ use utf8;
 
 use strict;
 use warnings;
+
 use Moose;
 use MooseX::AttributeShortcuts;
 use MooseX::Types::Moose qw(ArrayRef Bool Int Str);
+use Pod::Elemental::Element::Nested;
+use Pod::Elemental::Element::Pod5::Ordinary;
+
 with (
   'Pod::Weaver::Role::Section',
   'Dist::Zilla::Role::TextTemplate',
@@ -123,7 +126,7 @@ Pod::Weaver::Section::GenerateSection - add pod section from an interpolated pie
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -134,7 +137,7 @@ In your F<weaver.ini>
   text  = This is the POD for distribution {{$name}}. Check out what we have
   text  = been up to at {{$homepage}}
 
-The title value can be ommited if passed as the plugin name:
+The title value can be omited if passed as the plugin name:
 
   [GenerateSection / HOMEPAGE]
 
@@ -144,8 +147,8 @@ This plugin attempts to be a cross between L<Pod::Weaver::Section::Template> and
 L<Dist::Zilla::Plugin::GenerateFile> without the generation of extra files.
 
 The values of text are concatenated and variable names with matching values on
-the distribution are interpolated. Specifying the heading level allows to write
-down a rather long section of POD text without need for extra files. For
+the distribution are interpolated. Specifying the heading level allows one to
+write down a rather long section of POD text without need for extra files. For
 example:
 
   [GenerateSection / FEEDBACK]
@@ -221,7 +224,7 @@ Carnë Draug <cdraug@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Carnë Draug.
+This software is Copyright (c) 2013-2017 by Carnë Draug.
 
 This is free software, licensed under:
 
